# Generated by Django 5.2.10 on 2026-02-06 14:13

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("testapp", "0002_country_city_venue_event"),
    ]

    operations = [
        migrations.DeleteModel(
            name="Profile",
        ),
    ]
